@@ -3,7 +3,7 @@ package DhMakePerl::Command::Packaging;
 use strict;
 use warnings;
 
-our $VERSION = '0.91';
+our $VERSION = '0.93';
 
 use feature 'switch';
 
@@ -119,14 +119,27 @@ sub makefile_pl {
     return $self->main_file('Makefile.PL');
 }
 
-sub get_developer {
+sub get_email {
     my $self = shift;
-
     my $email = $self->cfg->email;
 
-    my ( $user, $pwnam, $name, $mailh );
-    $user = $ENV{LOGNAME} || $ENV{USER};
-    $pwnam = getpwuid($<);
+    $email ||= ( $ENV{DEBEMAIL} || $ENV{EMAIL} );
+    unless ($email) {
+	my $mailh;
+        chomp( $mailh = `cat /etc/mailname` );
+        $email = $self->get_user . '@' . $mailh;
+    }
+
+    $email =~ s/^(.*)\s+<(.*)>$/$2/;
+    return $email;
+}
+
+sub get_name {
+    my $self = shift;
+
+    my $name;
+    my $user = $ENV{LOGNAME} || $ENV{USER};
+    my $pwnam = getpwuid($<);
     die "Cannot determine current user\n" unless $pwnam;
     if ( defined $ENV{DEBFULLNAME} ) {
         $name = $ENV{DEBFULLNAME};
@@ -137,15 +150,12 @@ sub get_developer {
     }
     $user ||= $pwnam->name;
     $name ||= $user;
-    $email ||= ( $ENV{DEBEMAIL} || $ENV{EMAIL} );
-    unless ($email) {
-        chomp( $mailh = `cat /etc/mailname` );
-        $email = $user . '@' . $mailh;
-    }
+    return $name;
+}
 
-    $email =~ s/^(.*)\s+<(.*)>$/$2/;
-
-    return "$name <$email>";
+sub get_developer {
+    my $self = shift;
+    return $self->get_name . " <" . $self->get_email . ">";
 }
 
 sub fill_maintainer {
@@ -356,8 +366,14 @@ sub extract_name_ver {
         $ver  = $self->version;
     }
 
-    $ver = $self->cfg->version
-        if $self->cfg->version;
+    if ($self->cfg->version) {
+        #Version specified on command line trumps other versions
+        $ver = $self->cfg->version
+    } elsif ( $self->mod_cpan_version ) {
+        if ($self->mod_cpan_version != $ver) {
+            die "Version ambiguity, cpan has ".$self->mod_cpan_version.", module has ".$ver.". Please specify version with --version.\n";
+        }
+    }
 
     # final sanitazing of name and version
     $name =~ s/::/-/g if defined $name;
@@ -661,16 +677,16 @@ sub extract_desc {
     my ( $self, $file ) = @_;
 
     my $bin = $self->control->binary_tie->Values(0);
-    my $desc = $bin->short_description;
+    my $short_desc = $bin->short_description;
 
-    $desc and return;
+    $short_desc and return;
 
     return unless -f $file;
     my ( $parser, $modulename );
     $parser = new DhMakePerl::PodParser;
     $parser->set_names(qw(NAME DESCRIPTION DETAILS));
     $parser->parse_from_file($file);
-    if ( $desc ) {
+    if ( $short_desc ) {
 
         # No-op - We already have it, probably from the command line
 
@@ -678,7 +694,7 @@ sub extract_desc {
     elsif ( $self->meta->{abstract} ) {
 
         # Get it from META.yml
-        $desc = $self->meta->{abstract};
+        $short_desc = $self->meta->{abstract};
 
     }
     elsif ( my $my_desc = $parser->get('NAME') ) {
@@ -689,20 +705,21 @@ sub extract_desc {
         $my_desc =~ s/\s+$//s;
         $my_desc =~ s/^([^\s])/ $1/mg;
         $my_desc =~ s/\n.*$//s;
-        $desc = $my_desc;
+        $short_desc = $my_desc;
     }
 
-    if ( defined($desc) ) {
+    if ( defined($short_desc) ) {
         # Replace linefeed (not followed by a space) in short description with
         # spaces
-        $desc =~ s/\n(?=\S)/ /gs;
-        $desc =~ s/^\s+//;      # strip leading spaces
+        $short_desc =~ s/\n(?=\S)/ /gs;
+        $short_desc =~ s/^\s+//;                   # strip leading spaces
+        $short_desc =~ s/^(?:(A|An|The))\s+//i;    # strip leading article
     }
 
     # have a fall-back for the short description
-    $desc ||= '(no short description found)';
+    $short_desc ||= '(no short description found)';
 
-    $bin->short_description($desc);
+    $bin->short_description($short_desc);
 
     my $long_desc;
     unless ( $bin->long_description ) {
@@ -711,8 +728,7 @@ sub extract_desc {
             || $parser->get('DETAILS')
             || '';
         ( $modulename = $self->perlname ) =~ s/-/::/g;
-        $long_desc =~ s/This module/$modulename/;
-        $long_desc =~ s/This library/$modulename/;
+        $long_desc =~ s/This (?:module|library|plugin)/$modulename/;
 
         local ($Text::Wrap::columns) = 78;
         $long_desc = fill( "", "", $long_desc );
@@ -1428,7 +1444,7 @@ sub discover_dependencies {
     }
     else {
         warn "No APT contents can be loaded.\n";
-        warn "Please install 'apt-file' package (at least version 2.5.0) and\n";
+        warn "Please install the 'apt-file' package (at least version 3) and\n";
         warn "run 'apt-file update' as root.\n";
         warn "Dependencies not updated.\n";
 
