@@ -2,7 +2,7 @@ package DhMakePerl::Command::make;
 
 use warnings;
 use strict;
-our $VERSION = '0.91';
+our $VERSION = '0.93';
 use 5.010;    # we use smart matching
 
 use base 'DhMakePerl::Command::Packaging';
@@ -744,11 +744,13 @@ sub git_import_upstream__init_debian {
     $self->reset_git_environment();
 
     Git::command( 'init', $self->main_dir );
+    my @git_config = ( '-c', 'user.name=' . $self->get_name,
+                       '-c', 'user.email=' . $self->get_email);
 
     my $git = Git->repository( $self->main_dir );
     $git->command( qw(symbolic-ref HEAD refs/heads/upstream) );
     $git->command( 'add', '.' );
-    $git->command( 'commit', '-m',
+    $git->command( @git_config, 'commit', '-m',
               "Import original source of "
             . $self->perlname . ' '
             . $self->version );
@@ -762,7 +764,7 @@ sub git_import_upstream__init_debian {
       # debian/ directory from the working tree; git has the history, so I don't
       # need the debian.bak
       $git->command( 'rm', '-r', $self->debian_dir );
-      $git->command( 'commit', '-m',
+      $git->command( @git_config, 'commit', '-m',
                      'Removed debian directory embedded in upstream source' );
     }
 }
@@ -776,8 +778,12 @@ sub git_add_debian {
     $self->reset_git_environment;
 
     my $git = Git->repository( $self->main_dir );
+    my $name = $self->get_name;
+    my $email = $self->get_email;
+    my @git_config = ( '-c', "user.name=$name",
+                       '-c', "user.email=$email");
     $git->command( 'add', 'debian' );
-    $git->command( 'commit', '-m',
+    $git->command( @git_config, 'commit', '-m',
         "Initial packaging by dh-make-perl $VERSION" );
     $git->command(
         qw( remote add origin ),
@@ -788,8 +794,14 @@ sub git_add_debian {
     if ( File::Which::which('pristine-tar') ) {
         if ( $tarball and -f $tarball ) {
             $ENV{GIT_DIR} = File::Spec->catdir( $self->main_dir, '.git' );
-            system( 'pristine-tar', 'commit', $tarball, "upstream/".$self->version ) >= 0
-                or warn "error running pristine-tar: $!\n";
+            my %backup_ENV = %ENV;
+            $ENV{GIT_COMMITTER_NAME} = $name;
+            $ENV{GIT_COMMITTER_EMAIL} = $email;
+            $ENV{GIT_AUTHOR_NAME} = $name;
+            $ENV{GIT_AUTHOR_EMAIL} = $email;
+            my $status = system( 'pristine-tar', 'commit', $tarball, "upstream/".$self->version );
+            %ENV = %backup_ENV;
+            warn "error running pristine-tar: $!\n" if $status < 0;
         }
         else {
             die "No tarball found to handle with pristine-tar. Bailing out."
